
*********************************************************** REPLICATION CODE FOR "REFUSING TO KNOW A WOMAN'S PLACE"
*********************************************************** BY AMY ERICA SMITH, KATHERINE WARMING, AND VALERIE HENNINGS
*********************************************************** FORTHCOMING, POLITICS, GROUPS, AND IDENTITIES

***************** THIS CODE UTILIZES DATA FROM THE AMERICASBAROMETER 2012
***************** TO ACCESS THESE DATA, PLEASE SEE WWW.AMERICASBAROMETER.ORG

**** MODIFY THE FOLLOWING PATHS AS NECESSARY
use "AmericasBarometer Merged 2012 v49.0 English.dta", clear
*cd ""
xtset pais

recode vb51 vb52 (.a .b .c = .)
lab var vb51 "Who is Less Corrupt?"
	lab def vb51 1 "A woman" 2 "A man" 3 "Both the same", modify
	lab val vb51 vb51
lab var vb52 "Which is Better at Economy?"

recode vb51 (1=2) (3=1) (2=0), g(vb51r)
recode vb52 (1=0) (2=2) (3=1), g(vb52r)
lab def vb51r 0 "Woman" 1 "Equal" 2 "Man", modify
lab val vb51r vb51r
lab def vb52r 0 "Man" 1 "Equal" 2 "Woman", modify
lab val vb52r vb52r
egen profemaleleadership = rowmean(vb51r vb52r)

egen profemale = anycount(vb51r vb52r), values(2)
egen promale = anycount(vb51r vb52r), values(0)

recode vb51 (2 3 = 0), g(mancorrupt) 
recode vb51 (1 3 = 0) (2 = 1), g(womancorrupt)
recode vb51 (1 2 = 0) (3 = 1), g(equal_corrupt)
recode vb52 (2 3 = 0), g(maneconomy)
recode vb52 (1 3 = 0) (2 = 1), g(womaneconomy)
recode vb52 (1 2 = 0) (3 = 1), g(equal_economy)
lab var mancorrupt "Men are More Corrupt"
lab var womancorrupt "Women are More Corrupt"
lab var womaneconomy "Women are Better at Economy"
lab var maneconomy "Men are Better at Economy"
lab var equal_economy "Both Equal on Economy"
lab var equal_corrupt "Both Equal on Corruption"

g summary = 0 if womaneconomy == 1 & mancorrupt == 1
replace summary = 2 if equal_economy == 1 & equal_corrupt == 1
replace summary = 1 if maneconomy == 1 & womancorrupt == 1
replace summary = 3 if summary == . & vb51 < . & vb52 < .
lab def summary 0 "Two Pro-Female Stereotypes" 2 "Stereotype Rejection" 1 "Two Pro-Male Stereotypes" 3 "Other"
lab val summary summary

g stereotyperejection = (equal_corrupt & equal_economy) if vb51 < . | vb52 < .
g neutral_v_ambivalent = (stereotyperejection == 1) if profemaleleadership == 1

drop vb50r
g vb50r = 4 - vb50
lab var vb50r "Men Make Better Political Leaders"
lab def vb50r 0 "Strongly Disagree" 1 "Disagree" 2 "Agree" 3 "Strongly Agree", modify
lab val vb50r vb50r

replace gen6r = gen6r/100
lab var gen6r "Support for Gender Quotas"

******************************** INDEPENDENT VARIABLES/CONTROLS

replace psa5r = PSA5/100
lab var psa5r "Support for the Political System" 

replace ing4r = (ing4-1)/6
lab var ing4 "Support for Democracy"

replace l1 = l1b if l1 >= . & l1b < .
g leftism = (10-l1)/9
replace leftism = .5 if l1 > .
lab var leftism "Leftism"

*** authoritarianism
recode ab1 (1 = 0) (2 = 1) (3 = .5), g(ab1r)
recode ab2 (2 = 0) (3 = .5), g(ab2r)
recode ab5 (1 = 0) (2 = 1) (3 = .5), g(ab5r)
alpha ab1r ab2r ab5r, item
egen authoritarianism = rowmean(ab1r ab2r ab5r)
lab var authoritarianism "Authoritarianism"

g maleinterviewer = 2-sexi
lab var maleinterviewer "Male Interviewer"
replace maleinterviewer = 0 if pais > 39

/*
g samesexinterviewer = ((mujer == 0 & femaleinterviewer == 0) | (mujer == 1 & femaleinterviewer == 1))
tab samesexinterviewer mujer
replace samesexinterviewer = . if pais >= 40
*/

recode q11 (1 4/6 = 0) (2/3 = 1), g(haspartner)
lab var haspartner "Married/Common Law Married"

/*
g homemaker = ocup4a == 5 if ocup4a < .
lab var homemaker "Homemaker"
recode homemaker (1=0) if mujer == 0
*/
*** women in the workplace
replace gen1r = (7-gen1)/6
lab var gen1r "Support for Women's Labor Participation"

replace edr = edr/3
replace edad = (edad-1)/5

replace pol1r = pol1r/100
lab var pol1r "Political Interest"


*********************** ADD IN CONTEXTUAL DATA
 
preserve
insheet using "Contextual data\Contextual Variable Data 3.csv", clear
cap save "Contextual data\contextualdata.dta"
cap save "Contextual data\contextualdata.dta", replace
g pais = 17 if country == "Argentina"
replace pais = 26 if country == "Belize"
replace pais = 10 if country == "Bolivia"
replace pais = 15 if country == "Brazil"
replace pais = 41 if country == "Canada"
replace pais = 13 if country == "Chile"
replace pais = 8 if country == "Colombia"
replace pais = 6 if country == "Costa Rica"
replace pais = 21 if country == "Dominican Republic"
replace pais = 9 if country == "Ecuador"
replace pais = 3 if country == "El Salvador"
replace pais = 2 if country == "Guatemala"
replace pais = 24 if country == "Guyana"
replace pais = 22 if country == "Haiti"
replace pais = 4 if country == "Honduras"
replace pais = 23 if country == "Jamaica"
replace pais = 1 if country == "Mexico"
replace pais = 5 if country == "Nicaragua"
replace pais = 7 if country == "Panama"
replace pais = 12 if country == "Paraguay"
replace pais = 11 if country == "Peru"
replace pais = 27 if country == "Suriname"
replace pais = 25 if country == "Trinidad and Tobago"
replace pais = 40 if country == "United States"
replace pais = 14 if country == "Uruguay"
replace pais = 16 if country == "Venezuela"
replace femaleprofessionals = "" if femaleprofessionals == "N/A" 
replace unicamerallowerhousefemales = "" if unicamerallowerhousefemales == "N/A" 
replace totalfemalelegislators = "" if totalfemalelegislators == "N/A" 
replace leaderideology = "" if leaderideology == "N/A" 
replace genderquotalaws = "" if genderquotalaws == "N/A" 
destring femaleprofessionals unicamerallowerhousefemales totalfemalelegislators leaderideology gdppercapitappp genderquotalaws, replace
g leaderideology2 = 0 if leaderideology == "Left"
replace leaderideology2 = 1 if leaderideology == "Center"
replace leaderideology2 = 2 if leaderideology == "Right"
drop leaderideology
lab def leaderideology2 0 "Left" 1 "Center" 2 "Right"
lab val leaderideology2 leaderideology2
lab var leaderideology2 "Leader Ideology"
rename leaderideology2 leaderideology
recode genderquotalaws (. = 0), g(genderquotalaws_nomiss)
capture lab var qenderquotalaws_nomiss "Gender Quota Law"
save "Contextual data\contextualdata.dta", replace
restore

merge m:1 pais using "Contextual data\contextualdata.dta"
drop _merge

*** Human Development Index

generate hdi07=0.854 if pais==1 
replace hdi07=0.704 if pais==2
replace hdi07=0.7473 if pais== 3
replace hdi07=0.732 if pais==4
replace hdi07=0.699 if pais==5
replace hdi07=0.854 if pais==6
replace hdi07=0.84 if pais==7
replace hdi07=0.807 if pais==8
replace hdi07=0.806 if pais==9
replace hdi07=0.729 if pais==10
replace hdi07=0.806 if pais==11
replace hdi07=0.761 if pais==12
replace hdi07=0.878 if pais==13
replace hdi07=0.865 if pais==14
replace hdi07=0.813 if pais==15
replace hdi07=0.844 if pais==16
replace hdi07=0.866 if pais==17
replace hdi07=0.777 if pais==21
replace hdi07=0.532 if pais==22
replace hdi07=0.766 if pais==23
replace hdi07=0.729 if pais==24
replace hdi07=0.837 if pais==25
replace hdi07=0.772 if pais==26
replace hdi07=0.769 if pais==27
replace hdi07=0.956 if pais==40
replace hdi07=0.966 if pais==41
label variable hdi07 "Human Development Index"

*** Education Index

generate edindex=0.886 if pais==1 
replace edindex=0.723 if pais==2
replace edindex=0.794 if pais==3
replace edindex=0.806 if pais==4
replace edindex=0.76 if pais==5
replace edindex=0.883 if pais==6
replace edindex=0.888 if pais==7
replace edindex=0.881 if pais==8
replace edindex=0.866 if pais==9
replace edindex=0.892 if pais==10
replace edindex=0.891 if pais==11
replace edindex=0.871 if pais==12
replace edindex=0.919 if pais==13
replace edindex=0.955 if pais==14
replace edindex=0.891 if pais==15
replace edindex=0.921 if pais==16
replace edindex=0.946 if pais==17
replace edindex=0.839 if pais==21
replace edindex=0.588 if pais==22
replace edindex=0.834 if pais==23
replace edindex=0.939 if pais==24
replace edindex=0.861 if pais==25
replace edindex=0.762 if pais==26
replace edindex=0.85 if pais==27
replace edindex=0.968 if pais==40
replace edindex=0.991 if pais==41
label variable edindex "Education Index"

*** Freedom House Inverted

generate freehinv=9 if pais==1 
replace freehinv=7 if pais==2 
replace freehinv=9 if pais==3 
replace freehinv=8 if pais==4 
replace freehinv=7 if pais==5 
replace freehinv=12 if pais==6 
replace freehinv=11 if pais==7 
replace freehinv=7 if pais==8
replace freehinv=8 if pais==9 
replace freehinv=8 if pais==10 
replace freehinv=9 if pais==11 
replace freehinv=8 if pais==12
replace freehinv=12 if pais==13 
replace freehinv=12 if pais==14
replace freehinv=10 if pais==15
replace freehinv=6 if pais==16
replace freehinv=10 if pais==17 
replace freehinv=10 if pais==21
replace freehinv=5 if pais==22
replace freehinv=9 if pais==23
replace freehinv=9 if pais==24
replace freehinv=10 if pais==25 
replace freehinv=11 if pais==26
replace freehinv=10 if pais==27
replace freehinv=12 if pais==40
replace freehinv=12 if pais==41
label variable freehinv "Freedom House Inverted"

*** Electoral System Chamber 1

generate elecsys=1 if pais==1
replace elecsys=2 if pais==2
replace elecsys=2 if pais==3
replace elecsys=2 if pais==4
replace elecsys=2 if pais==5
replace elecsys=2 if pais==6
replace elecsys=2 if pais==7
replace elecsys=2 if pais==8
replace elecsys=2 if pais==9
replace elecsys=3 if pais==10
replace elecsys=2 if pais==11
replace elecsys=2 if pais==12
replace elecsys=2 if pais==13
replace elecsys=2 if pais==14
replace elecsys=2 if pais==15
replace elecsys=3 if pais==16
replace elecsys=2 if pais==17
replace elecsys=2 if pais==21
replace elecsys=5 if pais==22
replace elecsys=4 if pais==23
replace elecsys=2 if pais==24
replace elecsys=4 if pais==25
replace elecsys=4 if pais==26
replace elecsys=2 if pais==27
replace elecsys=4 if pais==40
replace elecsys=4 if pais==41
label variable elecsys "Electoral System Chamber 1"
label define elecsys_label 1 "PR Lists and Plurality (FPTP)" 2 "PR Lists" 3 "Mixed Member Proportional" 4 "Plurality (FPTP)" 5"Two-round system"
label values elecsys elecsys_label

recode elecsys (1/3 = 0) (4/5 = 1), g(majoritarian)
lab def majoritarian 0 "Proportional" 1 "Majoritarian"
lab val majoritarian majoritarian
lab var majoritarian "Majoritarian"

rename unicamerallowerhousefemales legiswomen
replace legiswomen = legiswomen/100
replace femalelaborforce = femalelaborforce/100

**************************** VOTING FOR A FEMALE CANDIDATE

/* COUNTRIES WITH FEMALE CANDIDATES IN ELECTIONS (as coded, excluding very minor candidates in some countries)
Argentina	Yes
Bolivia	Yes
Brazil	Yes
Colombia	Yes
Costa Rica	Yes
Ecuador	Yes
Guatemala	Yes
Haiti	Yes
Mexico	Yes
Panama	Yes
Paraguay	Yes
Peru	Yes
*** EXCLUDING T&T AND JAMAICA BECAUSE OF PARLIAMENTARY SYSTEM WITH SMDs; 
VOTES ARE FOR PARLIAMENTARIANS IN A CONSTITUENCY, NOT NECESSARILY FOR THE PARTY LEADER
*/

/* FEMALE CANDIDATES IN THESE ELECTIONS
Patricia Mercado del Partido Alternativ	105
partido accion de desarrollo nacional -	204
partido unionista - pu- patricia escoba	207
winaq/urng/ann - frente amplio - rigobe	210
Laura Chinchilla (PLN)	602
balbina herrera	701
noemí sanín	805
Martha Roldos Bucaram, Alianza Izquierd	903
Melba Jacome, Movimiento Tierra Fertil-	906
MUSPA (Ana María Flores)	1008
Keiko Fujimori (Fuerza 2011)	1102
Blanca Ovelar	1202
(1501) dilma( pt, pmdb, pdt, pcdob, psb	1501
(1503) marina silva (pv)	1503
Cristina Fernández de Kirchner - Frente	1701
Mirlande Marigat (RDNP)	2201
Josette Bijou (INDEPENDENT)	2210
*/

g election_femalecand = ((pais == 1) | (pais == 2) | (pais == 6) | (pais == 7) | (pais == 8) | (pais == 9) | (pais == 10) | (pais == 11) | ///
	(pais == 12) | (pais == 15) | (pais == 17) | (pais == 22)) if pais < 40

**** NOTE: VERY FEW SUPPORTERS OF WOMEN CANDIDATES IN MEXICO, COLOMBIA, ECUADOR, BOLIVIA
g election_femalecand2 = ((pais == 2) | (pais == 6) | (pais == 7) | (pais == 11) | ///
	(pais == 12) | (pais == 15) | (pais == 17) | (pais == 22)) if pais < 40

g voted_femalecand = (vb3 == 105 | vb3 == 204 | vb3 == 207 | vb3 == 210 ///
	| vb3 == 602 | vb3 == 701 | vb3 == 805 | vb3 == 903 | vb3 == 906 | vb3 ==  1008 | vb3 == 1102 | vb3 == 1202 | vb3 ==  1501 ///
	| vb3 == 1503 | vb3 == 1701 | vb3 == 2201 | vb3 == 2210 ) if election_femalecand == 1 & vb3 < . & vb3 > 77
	
g voted_femalecand2 = (vb3 == 105 | vb3 == 204 | vb3 == 207 | vb3 == 210 ///
	| vb3 == 602 | vb3 == 701 | vb3 == 805 | vb3 == 903 | vb3 == 906 | vb3 ==  1008 | vb3 == 1102 | vb3 == 1202 | vb3 ==  1501 ///
	| vb3 == 1503 | vb3 == 1701 | vb3 == 2201 | vb3 == 2210 ) if election_femalecand2 == 1 & vb3 < . & vb3 > 77

	
************************* CODING PARTISANSHIP
g haspid = 2-vb10
lab var haspid "Party Identifier"

* COPARTISAN and Opposition Partisan OF WOMAN CANDIDATE IN REDUCED LIST OF COUNTRIES
g copartisan = (vb11 == 211 | vb11 == 212 | vb11 == 602 | vb11 == 701 | vb11 == 1102 | vb11 == 1201 | vb11 == 1501 | vb11 == 1502 | vb11 == 1504 ///
	| vb11 == 1506 | vb11 == 1513 | vb11 == 1512 | vb11 == 1701 | vb11 == 1702 | vb11 == 2202) if election_femalecand2 == 1
g outpartisan = (haspid == 1 & copartisan == 0) if election_femalecand2 == 1

egen partisanship = mean(haspid), by(pais)
egen corruption = mean(EXCTOTRS), by(pais)
	
****************************************************** ANALYSIS PRESENTED IN PAPER *************************************************************************

**** FIGURE	1
preserve
recode stereotyperejection 1 = 100
graph bar stereotyperejection if pais < 41, over(pais, sort(stereotyperejection) descending) ///
	horizontal title("Percent Rejecting All Gendered Leadership" "Stereotypes, 2012", size(med) span color(black)) ytitle("") ysize(6) ///
	graphregion(fcolor(white)) bar(1, lcolor(black) fcolor(gs10)) ylabel(25 50 75) saving(figure1.gph, replace) ///
	note("Source: AmericasBarometer by LAPOP", span)
restore

******** TABLE 1
eststo clear
gsem (1.vb51 <- leftism gen1r authoritarianism maleinterviewer ing4r psa5r edr edad mujer haspartner quintall colorr ///
		hdi legiswomen genderquotalaws femalelaborforce M1[pais]) ///
	(3.vb51 <- leftism gen1r authoritarianism maleinterviewer ing4r psa5r edr edad mujer haspartner quintall colorr ///
		hdi legiswomen genderquotalaws femalelaborforce M2[pais]) ///
	, mlogit 
	*THIS MODEL HAS TWO SEPARATE RANDOM EFFECTS
eststo
gsem (i.vb52 <- leftism gen1r authoritarianism maleinterviewer ing4r psa5r edr edad mujer haspartner quintall colorr ///
		hdi legiswomen genderquotalaws femalelaborforce M1[pais]@1) ///
	, mlogit 
	*A MODEL WITH TWO SEPARATE RANDOM EFFECTS DOESN'T CONVERGE
eststo
esttab , b(3) se(3) star(^ .10 * .05 ** .01 *** .001) pr2 nogaps nopar unstack label
	
*** TESTS OF STATISTICAL SIGNIFICANCE: DIFFERENCE BETWEEN PROFEMALE AND NEUTRAL RESPONSE
eststo clear
xtlogit mancorrupt leftism gen1r authoritarianism maleinterviewer ing4r psa5r edr edad mujer haspartner quintall colorr hdi legiswomen genderquotalaws ///
	if vb51 != 2
	*THIS MODEL HAS TWO SEPARATE RANDOM EFFECTS
eststo
xtlogit womaneconomy leftism gen1r authoritarianism maleinterviewer ing4r psa5r edr edad mujer haspartner quintall colorr hdi legiswomen genderquotalaws ///
	if vb52 != 1
	*A MODEL WITH TWO SEPARATE RANDOM EFFECTS DOESN'T CONVERGE
eststo
esttab , b(3) se(3) star(^ .10 * .05 ** .01 *** .001) pr2 nogaps nopar unstack label


****************** FIGURE 2: Consequences of Stereotyping
preserve
collapse gen6 (semean) se_gen6=gen6 if pais < 40, by(summary)
drop if summary == .
g lb = gen6-2*se_gen6
g ub = gen6+2*se_gen6 
graph twoway (bar gen6 summary if summary == 0, lcolor(black) fcolor(gs3) barwidth(.7)) ///
			(bar gen6 summary if summary == 1, lcolor(black) fcolor(gs8) barwidth(.7)) ///
			(bar gen6 summary if summary == 2, lcolor(black) fcolor(gs13) barwidth(.7)) ///
			(bar gen6 summary if summary == 3, lcolor(black) fcolor(gs16) barwidth(.7)) ///
			(rspike lb ub summary, lcolor(black)), ///
	legend(off) xlabel(0 "Two Pro-Female Stereotypes" 2 "Stereotypes Rejected" 1 "Two Pro-Male Stereotypes" 3 "Mixed/Ambivalent") xtitle("") ///
	ytitle("Support for Gender Quotas" "(1-7 Scale)") ///
	graphregion(fcolor(white) lcolor(white)) name(gen6, replace)
restore
preserve
collapse voted_femalecand2 (semean) se=voted_femalecand2, by(summary)
drop if summary == .
g lb = voted_femalecand2-2*se
g ub = voted_femalecand2+2*se 
graph twoway (bar voted_femalecand2 summary if summary == 0, lcolor(black) fcolor(gs3) barwidth(.7)) ///
			(bar voted_femalecand2 summary if summary == 1, lcolor(black) fcolor(gs8) barwidth(.7)) ///
			(bar voted_femalecand2 summary if summary == 2, lcolor(black) fcolor(gs13) barwidth(.7)) ///
			(bar voted_femalecand2 summary if summary == 3, lcolor(black) fcolor(gs16) barwidth(.7)) ///
			(rspike lb ub summary, lcolor(black)), ///
	legend(off) xlabel(0 "Two Pro-Female Stereotypes" 2 "Stereotypes Rejected" 1 "Two Pro-Male Stereotypes" 3 "Mixed/Ambivalent") xtitle("") ///
	ytitle("Proportion Voting for" "Women Candidates") ///
	graphregion(fcolor(white) lcolor(white)) name(womanvote, replace)
restore
graph combine gen6 womanvote, ///
	title("Consequences of Stereotyping and Rejecting Stereotypes in Latin America", color(black) size(vlarge)) iscale(*1.6) ///
	note("Source: 2012 AmericasBarometer by LAPOP. Whiskers represent 95% confidence intervals. Analysis of voting for women" ///
	"based on Argentina, Brazil, Costa Rica, Guatemala, Haiti, Panama, Paraguay, and Peru.", span size(medium)) ///
	graphregion(fcolor(white) lcolor(white)) xsize(6.5) ysize(3) saving(figure2.gph, replace) 

****************************************************************** TABLE 2 
eststo clear
xtreg gen6 b2.vb51 i.vb52 ///
	gen1r authoritarianism maleinterviewer ing4r leftism edr edad mujer haspartner quintall colorr hdi legiswomen genderquotalaws femalelaborforce
eststo
esttab , b(3) se(3) star(^ .10 * .05 ** .01 *** .001) r2 nogaps nopar label wide

*** INDIVIDUAL HIERARCHICAL MODELS
xtreg gen6 b2.vb51 i.vb52 ///
	edr edad mujer haspartner quintall colorr hdi 
xtreg gen6 b2.vb51 i.vb52 ///
	edr edad mujer haspartner quintall colorr legiswomen
xtreg gen6 b2.vb51 i.vb52 ///
	edr edad mujer haspartner quintall colorr genderquotalaws 
xtreg gen6 b2.vb51 i.vb52 ///
	edr edad mujer haspartner quintall colorr femalelaborforce


****************************************************************** TABLE 3 
preserve
drop if vb52 >= .
eststo clear
xtlogit voted_femalecand2 b2.vb51 i.vb52 ///
	edr edad mujer haspartner quintall colorr 
eststo
xtlogit voted_femalecand2 b2.vb51 i.vb52##c.copartisan outpartisan ///
	edr edad mujer quintall colorr haspartner 
eststo
xtlogit voted_femalecand2 b2.vb51 i.vb52##c.legiswomen copartisan outpartisan ///
	edr edad mujer quintall colorr haspartner 
eststo
esttab , b(3) se(3) star(^ .10 * .05 ** .01 *** .001) r2 nogaps nopar label 
restore

**** TRYING OTHER HIERARCHICAL MODELS
eststo clear
xtlogit voted_femalecand2 b2.vb51 i.vb52##c.legiswomen  ///
	edr edad mujer haspartner quintall colorr hdi genderquotalaws
eststo
xtlogit voted_femalecand2 b2.vb51 i.vb52##c.genderquotalaws  ///
	edr edad mujer haspartner quintall colorr hdi legiswomen 
eststo
xtlogit voted_femalecand2 b2.vb51 i.vb52##c.hdi ///
	edr edad mujer haspartner quintall colorr legiswomen genderquotalaws  
eststo
xtlogit voted_femalecand2 b2.vb51 i.vb52##c.femalelaborforce ///
	edr edad mujer haspartner quintall colorr legiswomen genderquotalaws  
eststo

************* PREDICTED PROBABILITIES
preserve
g womaneconomyXcopartisan = womaneconomy*copartisan
g equaleconomyXcopartisan = equal_economy*copartisan
xtlogit voted_femalecand2 b2.vb51 womaneconomy equal_economy copartisan outpartisan womaneconomyXcopartisan equaleconomyXcopartisan ///
	edr edad mujer quintall colorr haspartner 
margins, noatlegend predict(pu0) ///
		at((mean) _all womaneconomy=0 equal_economy=0 copartisan=1 outpartisan=0 womaneconomyXcopartisan=0 equaleconomyXcopartisan=0 ) ///
		at((mean) _all womaneconomy=1 equal_economy=0 copartisan=1 outpartisan=0 womaneconomyXcopartisan=1 equaleconomyXcopartisan=0 ) ///
		at((mean) _all womaneconomy=0 equal_economy=1 copartisan=1 outpartisan=0 womaneconomyXcopartisan=0 equaleconomyXcopartisan=1 ) ///
		at((mean) _all womaneconomy=0 equal_economy=0 copartisan=0 outpartisan=0 womaneconomyXcopartisan=0 equaleconomyXcopartisan=0 ) ///
		at((mean) _all womaneconomy=1 equal_economy=0 copartisan=0 outpartisan=0 womaneconomyXcopartisan=0 equaleconomyXcopartisan=0 ) ///
		at((mean) _all womaneconomy=0 equal_economy=1 copartisan=0 outpartisan=0 womaneconomyXcopartisan=0 equaleconomyXcopartisan=0 ) ///
		at((mean) _all womaneconomy=0 equal_economy=0 copartisan=0 outpartisan=1 womaneconomyXcopartisan=0 equaleconomyXcopartisan=0 ) ///
		at((mean) _all womaneconomy=1 equal_economy=0 copartisan=0 outpartisan=1 womaneconomyXcopartisan=0 equaleconomyXcopartisan=0 ) ///
		at((mean) _all womaneconomy=0 equal_economy=1 copartisan=0 outpartisan=1 womaneconomyXcopartisan=0 equaleconomyXcopartisan=0 ) 
restore

**** STATISTICAL SIGNIFICANCE OF COEFFICIENTS FOR LEGISWOMEN INTERACTIONS:
xtlogit voted_femalecand2 b2.vb51 vb52##c.legiswomen copartisan outpartisan ///
	edr edad mujer quintall colorr haspartner 
lincom 2.vb52 + .042*2.vb52#c.legiswomen //Haiti
lincom 2.vb52 + .086*2.vb52#c.legiswomen // Brazil and Panama
lincom 2.vb52 + .13*2.vb52#c.legiswomen //Guat & Paraguay
lincom 2.vb52 + .215*2.vb52#c.legiswomen //Peru
lincom 2.vb52 + .38*2.vb52#c.legiswomen //Argentina & CR
lincom 2.vb52 + .19*2.vb52#c.legiswomen //stat sig above legiswomen = .19

eststo clear
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 2 // GUAT: not important
eststo
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 6 // CR: VERY IMPORTANT
eststo
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 7 // Panama: not important
eststo
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 11 //Peru: not important
eststo
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 12 //Paraguay: not important
eststo
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 15 //Brazil: not important
eststo
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 17 //Argentina: VERY IMPORTANT
eststo
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 22 //Haiti: not important
eststo
esttab , b(3) se(3) star(^ .10 * .05 ** .01 *** .001) keep(2.vb52 3.vb52) nogaps nopar label 

logit voted_femalecand2 b2.vb51 i.vb52##i.pais edr edad mujer quintall colorr haspartner 
lincom 2.vb52 + 2.vb52#2.pais
lincom 2.vb52 + 2.vb52#6.pais
lincom 2.vb52 + 2.vb52#7.pais
lincom 2.vb52 + 2.vb52#11.pais
lincom 2.vb52 + 2.vb52#12.pais
lincom 2.vb52 + 2.vb52#15.pais
lincom 2.vb52 + 2.vb52#17.pais
lincom 2.vb52 + 2.vb52#22.pais
lincom 3.vb52 + 3.vb52#2.pais
lincom 3.vb52 + 3.vb52#6.pais
lincom 3.vb52 + 3.vb52#7.pais
lincom 3.vb52 + 3.vb52#11.pais
lincom 3.vb52 + 3.vb52#12.pais
lincom 3.vb52 + 3.vb52#15.pais
lincom 3.vb52 + 3.vb52#17.pais
lincom 3.vb52 + 3.vb52#22.pais

logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 2 //Guat
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 6 //CR
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 7 //Panama
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 11 //Peru
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 12 //Paraguay
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 15 //Bra
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 17 //ARg
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)
logit voted_femalecand2 b2.vb51 i.vb52 edr edad mujer quintall colorr haspartner if pais == 22 //Haiti
margins, noatlegend ///
		at((mean) _all 1.vb52=1 2.vb52=0 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=1 3.vb52=0) ///
		at((mean) _all 1.vb52=0 2.vb52=0 3.vb52=1)

**** partisanship interaction in CR		
logit voted_femalecand2 b2.vb51 i.vb52##c.copartisan outpartisan ///
	edr edad mujer quintall colorr haspartner if pais == 6
tab voted_femalecand2 vb52 if pais == 6 & copartisan == 1, col
tab voted_femalecand2 vb52 if pais == 6 & haspid == 0, col
tab voted_femalecand2 vb52 if pais == 6 & outpartisan == 1, col
tab voted_femalecand2 vb52 if pais == 6 & copartisan == 0, col
		
***************************************************** APPENDIX **************************************************************************

******** Descriptives
recode mancorrupt womancorrupt equal_corrupt maneconomy womaneconomy equal_economy vb50rr gen6rr (1 = 100)
svy: mean mancorrupt womancorrupt equal_corrupt maneconomy womaneconomy equal_economy, over(pais)  // NO VALUES FOR CANADA
svy: mean vb50rr , over(pais) // VALUES FOR ALL COUNTRIES
svy: mean gen6rr , over(pais) // NO VALUES FOR US

***************************************************** IN-TEXT DISCUSSION ****************************************************************

******** Discussion
svy: tab vb51 vb52
svy: tab vb51 sexi, col 
svy: tab vb52 sexi, col
svy: tab vb51 sexi, col missing
svy: tab vb52 sexi, col missing
	

